@@ -15,25 +15,49 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from .firefox.webdriver import WebDriver as Firefox  # noqa
+from .chrome.options import Options as ChromeOptions  # noqa
+from .chrome.webdriver import WebDriver as Chrome  # noqa
+from .common.action_chains import ActionChains  # noqa
+from .common.desired_capabilities import DesiredCapabilities  # noqa
+from .common.keys import Keys  # noqa
+from .common.proxy import Proxy  # noqa
+from .edge.options import Options as EdgeOptions  # noqa
+from .edge.webdriver import WebDriver as ChromiumEdge  # noqa
+from .edge.webdriver import WebDriver as Edge  # noqa
 from .firefox.firefox_profile import FirefoxProfile  # noqa
 from .firefox.options import Options as FirefoxOptions  # noqa
-from .chrome.webdriver import WebDriver as Chrome  # noqa
-from .chrome.options import Options as ChromeOptions  # noqa
-from .ie.webdriver import WebDriver as Ie  # noqa
+from .firefox.webdriver import WebDriver as Firefox  # noqa
 from .ie.options import Options as IeOptions  # noqa
-from .edge.webdriver import WebDriver as Edge  # noqa
-from .opera.webdriver import WebDriver as Opera  # noqa
-from .safari.webdriver import WebDriver as Safari  # noqa
-from .blackberry.webdriver import WebDriver as BlackBerry  # noqa
-from .phantomjs.webdriver import WebDriver as PhantomJS  # noqa
-from .android.webdriver import WebDriver as Android  # noqa
-from .webkitgtk.webdriver import WebDriver as WebKitGTK # noqa
-from .webkitgtk.options import Options as WebKitGTKOptions # noqa
+from .ie.webdriver import WebDriver as Ie  # noqa
 from .remote.webdriver import WebDriver as Remote  # noqa
-from .common.desired_capabilities import DesiredCapabilities  # noqa
-from .common.action_chains import ActionChains  # noqa
-from .common.touch_actions import TouchActions  # noqa
-from .common.proxy import Proxy  # noqa
+from .safari.webdriver import WebDriver as Safari  # noqa
+from .webkitgtk.options import Options as WebKitGTKOptions  # noqa
+from .webkitgtk.webdriver import WebDriver as WebKitGTK  # noqa
+from .wpewebkit.options import Options as WPEWebKitOptions  # noqa
+from .wpewebkit.webdriver import WebDriver as WPEWebKit  # noqa
 
-__version__ = '3.13.0'
+__version__ = "4.8.1"
+
+# We need an explicit __all__ because the above won't otherwise be exported.
+__all__ = [
+    "Firefox",
+    "FirefoxProfile",
+    "FirefoxOptions",
+    "Chrome",
+    "ChromeOptions",
+    "Ie",
+    "IeOptions",
+    "Edge",
+    "ChromiumEdge",
+    "EdgeOptions",
+    "Safari",
+    "WebKitGTK",
+    "WebKitGTKOptions",
+    "WPEWebKit",
+    "WPEWebKitOptions",
+    "Remote",
+    "DesiredCapabilities",
+    "ActionChains",
+    "Proxy",
+    "Keys",
+]
